@@ -7,8 +7,8 @@
 from __future__ import print_function, division, absolute_import
 import os
 import logging
-import sys
 import json
+from typing import Callable, Dict, Optional, Union
 
 __version__ = ""
 with open(
@@ -25,52 +25,20 @@ from ads.common.ipython import configure_plotting, _log_traceback
 from ads.feature_engineering.accessor.series_accessor import ADSSeriesAccessor
 from ads.feature_engineering.accessor.dataframe_accessor import ADSDataFrameAccessor
 from ads.common import auth
+from ads.common.auth import set_auth
 
 os.environ["GIT_PYTHON_REFRESH"] = "quiet"
 
 
 debug_mode = os.environ.get("DEBUG_MODE", False)
 documentation_mode = os.environ.get("DOCUMENTATION_MODE", "False") == "True"
-oci_config_path = oci.config.DEFAULT_LOCATION  # "~/.oci/config"
-oci_key_profile = "DEFAULT"
 test_mode = os.environ.get("TEST_MODE", False)
-resource_principal_mode = bool(os.environ.get("RESOURCE_PRINCIPAL_MODE", False))
+resource_principal_mode = bool(
+    os.environ.get("RESOURCE_PRINCIPAL_MODE", False)
+)  # deprecated with is_resource_principal_mode() from ads.common.utils
 orig_ipython_traceback = None
 
 
-def set_auth(
-    auth="api_key", oci_config_location=oci.config.DEFAULT_LOCATION, profile="DEFAULT"
-):
-    """
-    Enable/disable resource principal identity or keypair identity in a notebook session.
-
-    Parameters
-    ----------
-    auth: {'api_key', 'resource_principal'}, default 'api_key'
-         Enable/disable resource principal identity or keypair identity in a notebook session
-    oci_config_location: str, default oci.config.DEFAULT_LOCATION, which is '~/.oci/config'
-        config file location
-    profile: str, default 'DEFAULT'
-         profile name for api keys config file
-    """
-    global resource_principal_mode
-    global oci_config_path
-    global oci_key_profile
-    oci_key_profile = profile
-
-    if auth == "api_key":
-        resource_principal_mode = False
-        if os.path.exists(os.path.expanduser(oci_config_location)):
-            oci_config_path = oci_config_location
-        else:
-            logging.warning(
-                f"{oci_config_location} file does not exist, default value oci.config.DEFAULT_LOCATION used instead"
-            )
-            oci_config_path = oci.config.DEFAULT_LOCATION
-    elif auth == "resource_principal":
-        resource_principal_mode = True
-
-
 def getLogger(name="ads"):
     logger = logging.getLogger(name)
     logger.setLevel(logging.WARNING)
